# Dimsum

Library built on top of GraphBLAS to behave more like a DataFrame than a Matrix.

A schema made of Dimensions is defined upfront and provides the foundation for elegant
dimensional pivoting, reductions, and other manipulations.